#include "ehs/io/socket/HeaderVar.h"

namespace ehs
{
    HeaderVar::HeaderVar()
        : id(0)
    {
    }

    HeaderVar::HeaderVar(Str_8 name, Str_8 value)
        : id(name.Hash_64()), name((Str_8 &&)name), value((Str_8 &&)value)
    {
    }

    HeaderVar::HeaderVar(HeaderVar&& other) noexcept
        : id(other.id), name((Str_8 &&)other.name), value((Str_8 &&)other.value)
    {
        other.id = 0;
    }

    HeaderVar::HeaderVar(const HeaderVar& other)
        : id(other.id), name(other.name), value(other.value)
    {
    }

    HeaderVar& HeaderVar::operator=(HeaderVar&& other) noexcept
    {
        if (this == &other)
            return *this;

        id = other.id;
        name = (Str_8 &&)other.name;
        value = (Str_8 &&)other.value;

        other.id = 0;

        return *this;
    }

    HeaderVar& HeaderVar::operator=(const HeaderVar& other)
    {
        if (this == &other)
            return *this;

        id = other.id;
        name = other.name;
        value = other.value;

        return *this;
    }

    bool HeaderVar::operator==(const HeaderVar& other) const
    {
        return id == other.id;
    }

    bool HeaderVar::operator!=(const HeaderVar& other) const
    {
        return id != other.id;
    }

    bool HeaderVar::operator==(const UInt_64& otherId) const
    {
        return id == otherId;
    }

    bool HeaderVar::operator!=(const UInt_64& otherId) const
    {
        return id != otherId;
    }

    UInt_64 HeaderVar::GetId() const
    {
        return id;
    }

    Str_8 HeaderVar::GetName() const
    {
        return name;
    }

    Str_8 HeaderVar::GetValue() const
    {
        return value;
    }

    void HeaderVar::SetValue(Str_8 value)
    {
        this->value = (Str_8 &&)value;
    }

    Str_8 HeaderVar::ToStr() const
    {
        return name + ": " + value;
    }
}
